@@ -1,4 +1,4 @@
-#  Tests for the neotoma package.  Mostly validating that changes to the functions
+#  Tests for the neotoma package.  Mostly validating to make sure changes to the functions
 #  do not break the requirements for data formatting.
 
 library("testthat")
@@ -17,7 +17,8 @@ block_one <- function(){
 
 test_that('some of the functions in the paper still work', 
 {
-  expect_true(nrow(get_site(sitename = 'Marion Lake%')) == 1)
+  # This has changed as sites have been added.
+  expect_is(get_site(sitename = 'Marion Lake%'), c("site", "data.frame"))
   expect_true(nrow(get_site(sitename = 'Louise Pond%')) == 1)
   expect_is(block_one(), 'download_list')
   expect_is(get_site(loc = c(-140, 45, -110, 65)), 'site')
